@@ -998,6 +998,9 @@ class SimulatedMovieGenerator:
                  range_n_transient_cells_of_interest=(2, 4),
                  range_n_transient_overlapping_cells=(8, 16),
                  range_n_transient_other_cells=(2, 16),
+                 range_duration_transient=(1, 8),
+                 decay_factor=10,
+                 max_decay=12,
                  time_str=None, use_only_valid_cells=True):
         """
         
@@ -1019,6 +1022,10 @@ class SimulatedMovieGenerator:
             for cells that are not of interest or overlap them
             use_only_valid_cells: Cells models could be classify as Valid or False (using a classifier for exemple).
             This allow for the movie to be generated with ROIs that would have the rightly segmented cell
+            decay_factor: use to calculate the length of decay (in frames) according to this formula
+            len_decay = max(len_period * decay_factor, max_decay)
+            max_decay: use to calculate the length of decay (in frames) according to this formula
+            len_decay = max(len_period * decay_factor, max_decay)
             path_results: Directory in which to save the results
             time_str (string): id (meant to be a timestamps string representation) in order to  give a unique id to files.
         """
@@ -1039,6 +1046,12 @@ class SimulatedMovieGenerator:
 
         self.n_frames = n_frames
 
+        self.range_duration_transient = range_duration_transient
+
+        self.decay_factor = decay_factor
+
+        self.max_decay = max_decay
+
         self.path_results = path_results
 
         # --------- generate_artificial_map section ---------
@@ -1338,7 +1351,9 @@ class SimulatedMovieGenerator:
             onsets.sort()
             for transient in np.arange(n_transient):
                 onset = onsets[transient]
-                duration_transient = random.randint(1, 8)
+                # duration_transient = random.randint(1, 8)
+                duration_transient = random.randint(self.range_duration_transient[0],
+                                                    self.range_duration_transient[1])
                 raster_dur[cell, onset:onset + duration_transient] = 1
 
         plot_spikes_raster(spike_nums=raster_dur, path_results=self.path_results,
@@ -1363,7 +1378,6 @@ class SimulatedMovieGenerator:
         n_cells = self.raster_dur.shape[0]
         n_frames = self.raster_dur.shape[1]
 
-        decay_factor = 10
         traces = np.ones((n_cells, n_frames))
         original_baseline = baseline
         # cell_baseline_ratio: by how much increasing the baseline of the cell comparing to the baseline of map
@@ -1404,7 +1418,7 @@ class SimulatedMovieGenerator:
                     raise Exception("ValueError: could not broadcast input array from shape (3) into shape (2)")
                 if (last_frame + 1) == n_frames:
                     continue
-                len_decay = max(len_period * decay_factor, 12)
+                len_decay = max(len_period * self.decay_factor, self.max_decay)
                 growth_rate = finding_growth_rate(t=len_decay, a=amplitude_max, end_value=baseline)
                 traces_decay_values = exponential_decay_formula(t=np.arange(len_decay), a=amplitude_max,
                                                                 k=growth_rate, c=0)
