@@ -216,6 +216,59 @@ def check_one_dir_by_id_exists(identifiers, results_path, dir_in_id_name=False):
     return True
 
 
+def norm01(data):
+    """
+    Normalize an array so that values are ranging between 0 and 1
+    Args:
+        data: numpy array
+
+    Returns:
+
+    """
+    data = np.copy(data).astype("float")
+    min_value = np.min(data)
+    max_value = np.max(data)
+
+    difference = max_value - min_value
+
+    data -= min_value
+
+    if difference > 0:
+        data = data / difference
+
+    return data
+
+def get_tree_dict_as_a_list(tree_dict):
+    """
+    Consider a dict representing a tree (the tree leaves are string), it returns list of all paths from
+    root node to all leaves
+    Args:
+        tree_dict:
+
+    Returns:
+
+    """
+    tree_as_list = []
+    for key, sub_tree in tree_dict.items():
+        if isinstance(sub_tree, dict):
+            # recursive function
+            branches = get_tree_dict_as_a_list(tree_dict=sub_tree)
+            tree_as_list.extend([[key] + branch for branch in branches])
+        elif isinstance(sub_tree, list):
+            # means we reached leaves
+            leaves = sub_tree
+            for leaf in leaves:
+                tree_as_list.append([key, leaf])
+        else:
+            # means we reached a leaf
+            leaf = sub_tree
+            # checking if the leaf is not None
+            if leaf is None:
+                tree_as_list.append([key])
+            else:
+                tree_as_list.append([key, leaf])
+    return tree_as_list
+
 def create_one_npy_file_by_frame(movies_to_split, results_path,
                                 without_mean_std_files=False, verbose=0):
     """
@@ -427,7 +480,7 @@ def load_movie(file_name, with_normalization, both_instances=False, verbose=True
     """
     Load a movie in memory. So far only tiff format is valid
     Args:
-        file_name:
+        file_name: str for a file_name, or array representing the movie
         with_normalization: if True, normalize the movie using z-score formula
         both_instances: if with_normalization is True and both_instances is True, then
         the function return both movie, the normal and the normalized one in that order
@@ -435,25 +488,28 @@ def load_movie(file_name, with_normalization, both_instances=False, verbose=True
     Returns:
 
     """
-    try:
-        start_time = time.time()
-        tiff_movie = ScanImageTiffReader(file_name).data()
-        stop_time = time.time()
-        if verbose:
-            print(f"Time for loading movie with ScanImageTiffReader: "
-                  f"{np.round(stop_time - start_time, 3)} s")
-    except Exception as e:
-        start_time = time.time()
-        im = PIL.Image.open(file_name)
-        n_frames = len(list(ImageSequence.Iterator(im)))
-        dim_y, dim_x = np.array(im).shape
-        tiff_movie = np.zeros((n_frames, dim_y, dim_x), dtype="uint16")
-        for frame, page in enumerate(ImageSequence.Iterator(im)):
-            tiff_movie[frame] = np.array(page)
-        stop_time = time.time()
-        if verbose:
-            print(f"Time for loading movie with PIL: "
-                  f"{np.round(stop_time - start_time, 3)} s")
+    if isinstance(file_name, str):
+        try:
+            start_time = time.time()
+            tiff_movie = ScanImageTiffReader(file_name).data()
+            stop_time = time.time()
+            if verbose:
+                print(f"Time for loading movie with ScanImageTiffReader: "
+                      f"{np.round(stop_time - start_time, 3)} s")
+        except Exception as e:
+            start_time = time.time()
+            im = PIL.Image.open(file_name)
+            n_frames = len(list(ImageSequence.Iterator(im)))
+            dim_y, dim_x = np.array(im).shape
+            tiff_movie = np.zeros((n_frames, dim_y, dim_x), dtype="uint16")
+            for frame, page in enumerate(ImageSequence.Iterator(im)):
+                tiff_movie[frame] = np.array(page)
+            stop_time = time.time()
+            if verbose:
+                print(f"Time for loading movie with PIL: "
+                      f"{np.round(stop_time - start_time, 3)} s")
+    else:
+        tiff_movie = file_name
     if with_normalization:
         tiff_movie_normalized = tiff_movie - np.mean(tiff_movie)
         tiff_movie_normalized = tiff_movie_normalized / np.std(tiff_movie)
